@@ -13,22 +13,22 @@ Usage::
     ```
 """
 from datetime import datetime
-from typing import Any, Dict, List, Type
+from typing import Any, Dict, List, Type, Union
 
 from botocore.client import ClientMeta
 
 from .type_defs import (
     ApplicationUpdateTypeDef,
     CloudWatchLoggingOptionTypeDef,
-    CreateApplicationResponseTypeDef,
-    DescribeApplicationResponseTypeDef,
-    DiscoverInputSchemaResponseTypeDef,
+    CreateApplicationResponseResponseTypeDef,
+    DescribeApplicationResponseResponseTypeDef,
+    DiscoverInputSchemaResponseResponseTypeDef,
     InputConfigurationTypeDef,
     InputProcessingConfigurationTypeDef,
     InputStartingPositionConfigurationTypeDef,
     InputTypeDef,
-    ListApplicationsResponseTypeDef,
-    ListTagsForResourceResponseTypeDef,
+    ListApplicationsResponseResponseTypeDef,
+    ListTagsForResourceResponseResponseTypeDef,
     OutputTypeDef,
     ReferenceDataSourceTypeDef,
     S3ConfigurationTypeDef,
@@ -64,7 +64,7 @@ class Exceptions:
 
 class KinesisAnalyticsClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kinesisanalytics.html#KinesisAnalytics.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html)
     """
 
@@ -76,18 +76,22 @@ class KinesisAnalyticsClient:
         *,
         ApplicationName: str,
         CurrentApplicationVersionId: int,
-        CloudWatchLoggingOption: CloudWatchLoggingOptionTypeDef
+        CloudWatchLoggingOption: "CloudWatchLoggingOptionTypeDef"
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_cloud_watch_logging_option)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_cloud_watch_logging_option)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#add_application_cloud_watch_logging_option)
         """
 
     def add_application_input(
-        self, *, ApplicationName: str, CurrentApplicationVersionId: int, Input: InputTypeDef
+        self, *, ApplicationName: str, CurrentApplicationVersionId: int, Input: "InputTypeDef"
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_input)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_input)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#add_application_input)
         """
 
@@ -100,15 +104,19 @@ class KinesisAnalyticsClient:
         InputProcessingConfiguration: "InputProcessingConfigurationTypeDef"
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_input_processing_configuration)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_input_processing_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#add_application_input_processing_configuration)
         """
 
     def add_application_output(
-        self, *, ApplicationName: str, CurrentApplicationVersionId: int, Output: OutputTypeDef
+        self, *, ApplicationName: str, CurrentApplicationVersionId: int, Output: "OutputTypeDef"
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_output)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_output)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#add_application_output)
         """
 
@@ -117,16 +125,20 @@ class KinesisAnalyticsClient:
         *,
         ApplicationName: str,
         CurrentApplicationVersionId: int,
-        ReferenceDataSource: ReferenceDataSourceTypeDef
+        ReferenceDataSource: "ReferenceDataSourceTypeDef"
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_reference_data_source)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.add_application_reference_data_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#add_application_reference_data_source)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#can_paginate)
         """
 
@@ -135,22 +147,26 @@ class KinesisAnalyticsClient:
         *,
         ApplicationName: str,
         ApplicationDescription: str = None,
-        Inputs: List[InputTypeDef] = None,
-        Outputs: List[OutputTypeDef] = None,
-        CloudWatchLoggingOptions: List[CloudWatchLoggingOptionTypeDef] = None,
+        Inputs: List["InputTypeDef"] = None,
+        Outputs: List["OutputTypeDef"] = None,
+        CloudWatchLoggingOptions: List["CloudWatchLoggingOptionTypeDef"] = None,
         ApplicationCode: str = None,
         Tags: List["TagTypeDef"] = None
-    ) -> CreateApplicationResponseTypeDef:
+    ) -> CreateApplicationResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.create_application)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.create_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#create_application)
         """
 
     def delete_application(
-        self, *, ApplicationName: str, CreateTimestamp: datetime
+        self, *, ApplicationName: str, CreateTimestamp: Union[datetime, str]
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#delete_application)
         """
 
@@ -162,7 +178,9 @@ class KinesisAnalyticsClient:
         CloudWatchLoggingOptionId: str
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_cloud_watch_logging_option)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_cloud_watch_logging_option)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#delete_application_cloud_watch_logging_option)
         """
 
@@ -170,7 +188,9 @@ class KinesisAnalyticsClient:
         self, *, ApplicationName: str, CurrentApplicationVersionId: int, InputId: str
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_input_processing_configuration)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_input_processing_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#delete_application_input_processing_configuration)
         """
 
@@ -178,7 +198,9 @@ class KinesisAnalyticsClient:
         self, *, ApplicationName: str, CurrentApplicationVersionId: int, OutputId: str
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_output)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_output)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#delete_application_output)
         """
 
@@ -186,13 +208,19 @@ class KinesisAnalyticsClient:
         self, *, ApplicationName: str, CurrentApplicationVersionId: int, ReferenceId: str
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_reference_data_source)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.delete_application_reference_data_source)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#delete_application_reference_data_source)
         """
 
-    def describe_application(self, *, ApplicationName: str) -> DescribeApplicationResponseTypeDef:
+    def describe_application(
+        self, *, ApplicationName: str
+    ) -> DescribeApplicationResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.describe_application)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.describe_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#describe_application)
         """
 
@@ -202,11 +230,13 @@ class KinesisAnalyticsClient:
         ResourceARN: str = None,
         RoleARN: str = None,
         InputStartingPositionConfiguration: "InputStartingPositionConfigurationTypeDef" = None,
-        S3Configuration: S3ConfigurationTypeDef = None,
+        S3Configuration: "S3ConfigurationTypeDef" = None,
         InputProcessingConfiguration: "InputProcessingConfigurationTypeDef" = None
-    ) -> DiscoverInputSchemaResponseTypeDef:
+    ) -> DiscoverInputSchemaResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.discover_input_schema)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.discover_input_schema)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#discover_input_schema)
         """
 
@@ -218,47 +248,63 @@ class KinesisAnalyticsClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#generate_presigned_url)
         """
 
     def list_applications(
         self, *, Limit: int = None, ExclusiveStartApplicationName: str = None
-    ) -> ListApplicationsResponseTypeDef:
+    ) -> ListApplicationsResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.list_applications)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.list_applications)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#list_applications)
         """
 
-    def list_tags_for_resource(self, *, ResourceARN: str) -> ListTagsForResourceResponseTypeDef:
+    def list_tags_for_resource(
+        self, *, ResourceARN: str
+    ) -> ListTagsForResourceResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.list_tags_for_resource)
+        Retrieves the list of key-value tags assigned to the application.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#list_tags_for_resource)
         """
 
     def start_application(
-        self, *, ApplicationName: str, InputConfigurations: List[InputConfigurationTypeDef]
+        self, *, ApplicationName: str, InputConfigurations: List["InputConfigurationTypeDef"]
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.start_application)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.start_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#start_application)
         """
 
     def stop_application(self, *, ApplicationName: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.stop_application)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.stop_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#stop_application)
         """
 
     def tag_resource(self, *, ResourceARN: str, Tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.tag_resource)
+        Adds one or more key-value tags to a Kinesis Analytics application.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#tag_resource)
         """
 
     def untag_resource(self, *, ResourceARN: str, TagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.untag_resource)
+        Removes one or more tags from a Kinesis Analytics application.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#untag_resource)
         """
 
@@ -267,9 +313,11 @@ class KinesisAnalyticsClient:
         *,
         ApplicationName: str,
         CurrentApplicationVersionId: int,
-        ApplicationUpdate: ApplicationUpdateTypeDef
+        ApplicationUpdate: "ApplicationUpdateTypeDef"
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.99/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.update_application)
+        .
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/kinesisanalytics.html#KinesisAnalytics.Client.update_application)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kinesisanalytics/client.html#update_application)
         """
