@@ -6,14 +6,14 @@ Type annotations for kinesisanalytics service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_kinesisanalytics.type_defs import ApplicationDetailTypeDef
+    from mypy_boto3_kinesisanalytics.type_defs import AddApplicationCloudWatchLoggingOptionRequestTypeDef
 
-    data: ApplicationDetailTypeDef = {...}
+    data: AddApplicationCloudWatchLoggingOptionRequestTypeDef = {...}
     ```
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Union
 
 from .literals import ApplicationStatusType, InputStartingPositionType, RecordFormatTypeType
 
@@ -24,6 +24,11 @@ else:
 
 
 __all__ = (
+    "AddApplicationCloudWatchLoggingOptionRequestTypeDef",
+    "AddApplicationInputProcessingConfigurationRequestTypeDef",
+    "AddApplicationInputRequestTypeDef",
+    "AddApplicationOutputRequestTypeDef",
+    "AddApplicationReferenceDataSourceRequestTypeDef",
     "ApplicationDetailTypeDef",
     "ApplicationSummaryTypeDef",
     "ApplicationUpdateTypeDef",
@@ -31,10 +36,18 @@ __all__ = (
     "CloudWatchLoggingOptionDescriptionTypeDef",
     "CloudWatchLoggingOptionTypeDef",
     "CloudWatchLoggingOptionUpdateTypeDef",
-    "CreateApplicationResponseTypeDef",
-    "DescribeApplicationResponseTypeDef",
+    "CreateApplicationRequestTypeDef",
+    "CreateApplicationResponseResponseTypeDef",
+    "DeleteApplicationCloudWatchLoggingOptionRequestTypeDef",
+    "DeleteApplicationInputProcessingConfigurationRequestTypeDef",
+    "DeleteApplicationOutputRequestTypeDef",
+    "DeleteApplicationReferenceDataSourceRequestTypeDef",
+    "DeleteApplicationRequestTypeDef",
+    "DescribeApplicationRequestTypeDef",
+    "DescribeApplicationResponseResponseTypeDef",
     "DestinationSchemaTypeDef",
-    "DiscoverInputSchemaResponseTypeDef",
+    "DiscoverInputSchemaRequestTypeDef",
+    "DiscoverInputSchemaResponseResponseTypeDef",
     "InputConfigurationTypeDef",
     "InputDescriptionTypeDef",
     "InputLambdaProcessorDescriptionTypeDef",
@@ -65,8 +78,10 @@ __all__ = (
     "LambdaOutputDescriptionTypeDef",
     "LambdaOutputTypeDef",
     "LambdaOutputUpdateTypeDef",
-    "ListApplicationsResponseTypeDef",
-    "ListTagsForResourceResponseTypeDef",
+    "ListApplicationsRequestTypeDef",
+    "ListApplicationsResponseResponseTypeDef",
+    "ListTagsForResourceRequestTypeDef",
+    "ListTagsForResourceResponseResponseTypeDef",
     "MappingParametersTypeDef",
     "OutputDescriptionTypeDef",
     "OutputTypeDef",
@@ -82,7 +97,58 @@ __all__ = (
     "S3ReferenceDataSourceTypeDef",
     "S3ReferenceDataSourceUpdateTypeDef",
     "SourceSchemaTypeDef",
+    "StartApplicationRequestTypeDef",
+    "StopApplicationRequestTypeDef",
+    "TagResourceRequestTypeDef",
     "TagTypeDef",
+    "UntagResourceRequestTypeDef",
+    "UpdateApplicationRequestTypeDef",
+)
+
+AddApplicationCloudWatchLoggingOptionRequestTypeDef = TypedDict(
+    "AddApplicationCloudWatchLoggingOptionRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "CurrentApplicationVersionId": int,
+        "CloudWatchLoggingOption": "CloudWatchLoggingOptionTypeDef",
+    },
+)
+
+AddApplicationInputProcessingConfigurationRequestTypeDef = TypedDict(
+    "AddApplicationInputProcessingConfigurationRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "CurrentApplicationVersionId": int,
+        "InputId": str,
+        "InputProcessingConfiguration": "InputProcessingConfigurationTypeDef",
+    },
+)
+
+AddApplicationInputRequestTypeDef = TypedDict(
+    "AddApplicationInputRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "CurrentApplicationVersionId": int,
+        "Input": "InputTypeDef",
+    },
+)
+
+AddApplicationOutputRequestTypeDef = TypedDict(
+    "AddApplicationOutputRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "CurrentApplicationVersionId": int,
+        "Output": "OutputTypeDef",
+    },
+)
+
+AddApplicationReferenceDataSourceRequestTypeDef = TypedDict(
+    "AddApplicationReferenceDataSourceRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "CurrentApplicationVersionId": int,
+        "ReferenceDataSource": "ReferenceDataSourceTypeDef",
+    },
 )
 
 _RequiredApplicationDetailTypeDef = TypedDict(
@@ -198,17 +264,96 @@ class CloudWatchLoggingOptionUpdateTypeDef(
     pass
 
 
-CreateApplicationResponseTypeDef = TypedDict(
-    "CreateApplicationResponseTypeDef",
+_RequiredCreateApplicationRequestTypeDef = TypedDict(
+    "_RequiredCreateApplicationRequestTypeDef",
+    {
+        "ApplicationName": str,
+    },
+)
+_OptionalCreateApplicationRequestTypeDef = TypedDict(
+    "_OptionalCreateApplicationRequestTypeDef",
+    {
+        "ApplicationDescription": str,
+        "Inputs": List["InputTypeDef"],
+        "Outputs": List["OutputTypeDef"],
+        "CloudWatchLoggingOptions": List["CloudWatchLoggingOptionTypeDef"],
+        "ApplicationCode": str,
+        "Tags": List["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateApplicationRequestTypeDef(
+    _RequiredCreateApplicationRequestTypeDef, _OptionalCreateApplicationRequestTypeDef
+):
+    pass
+
+
+CreateApplicationResponseResponseTypeDef = TypedDict(
+    "CreateApplicationResponseResponseTypeDef",
     {
         "ApplicationSummary": "ApplicationSummaryTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DescribeApplicationResponseTypeDef = TypedDict(
-    "DescribeApplicationResponseTypeDef",
+DeleteApplicationCloudWatchLoggingOptionRequestTypeDef = TypedDict(
+    "DeleteApplicationCloudWatchLoggingOptionRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "CurrentApplicationVersionId": int,
+        "CloudWatchLoggingOptionId": str,
+    },
+)
+
+DeleteApplicationInputProcessingConfigurationRequestTypeDef = TypedDict(
+    "DeleteApplicationInputProcessingConfigurationRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "CurrentApplicationVersionId": int,
+        "InputId": str,
+    },
+)
+
+DeleteApplicationOutputRequestTypeDef = TypedDict(
+    "DeleteApplicationOutputRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "CurrentApplicationVersionId": int,
+        "OutputId": str,
+    },
+)
+
+DeleteApplicationReferenceDataSourceRequestTypeDef = TypedDict(
+    "DeleteApplicationReferenceDataSourceRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "CurrentApplicationVersionId": int,
+        "ReferenceId": str,
+    },
+)
+
+DeleteApplicationRequestTypeDef = TypedDict(
+    "DeleteApplicationRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "CreateTimestamp": Union[datetime, str],
+    },
+)
+
+DescribeApplicationRequestTypeDef = TypedDict(
+    "DescribeApplicationRequestTypeDef",
+    {
+        "ApplicationName": str,
+    },
+)
+
+DescribeApplicationResponseResponseTypeDef = TypedDict(
+    "DescribeApplicationResponseResponseTypeDef",
     {
         "ApplicationDetail": "ApplicationDetailTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -219,15 +364,27 @@ DestinationSchemaTypeDef = TypedDict(
     },
 )
 
-DiscoverInputSchemaResponseTypeDef = TypedDict(
-    "DiscoverInputSchemaResponseTypeDef",
+DiscoverInputSchemaRequestTypeDef = TypedDict(
+    "DiscoverInputSchemaRequestTypeDef",
+    {
+        "ResourceARN": str,
+        "RoleARN": str,
+        "InputStartingPositionConfiguration": "InputStartingPositionConfigurationTypeDef",
+        "S3Configuration": "S3ConfigurationTypeDef",
+        "InputProcessingConfiguration": "InputProcessingConfigurationTypeDef",
+    },
+    total=False,
+)
+
+DiscoverInputSchemaResponseResponseTypeDef = TypedDict(
+    "DiscoverInputSchemaResponseResponseTypeDef",
     {
         "InputSchema": "SourceSchemaTypeDef",
         "ParsedInputRecords": List[List[str]],
         "ProcessedInputRecords": List[str],
         "RawInputRecords": List[str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 InputConfigurationTypeDef = TypedDict(
@@ -430,7 +587,6 @@ KinesisFirehoseOutputTypeDef = TypedDict(
     {
         "ResourceARN": str,
         "RoleARN": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -483,7 +639,6 @@ KinesisStreamsOutputTypeDef = TypedDict(
     {
         "ResourceARN": str,
         "RoleARN": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -510,7 +665,6 @@ LambdaOutputTypeDef = TypedDict(
     {
         "ResourceARN": str,
         "RoleARN": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -523,20 +677,37 @@ LambdaOutputUpdateTypeDef = TypedDict(
     total=False,
 )
 
-ListApplicationsResponseTypeDef = TypedDict(
-    "ListApplicationsResponseTypeDef",
+ListApplicationsRequestTypeDef = TypedDict(
+    "ListApplicationsRequestTypeDef",
+    {
+        "Limit": int,
+        "ExclusiveStartApplicationName": str,
+    },
+    total=False,
+)
+
+ListApplicationsResponseResponseTypeDef = TypedDict(
+    "ListApplicationsResponseResponseTypeDef",
     {
         "ApplicationSummaries": List["ApplicationSummaryTypeDef"],
         "HasMoreApplications": bool,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef",
+ListTagsForResourceRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestTypeDef",
+    {
+        "ResourceARN": str,
+    },
+)
+
+ListTagsForResourceResponseResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseResponseTypeDef",
     {
         "Tags": List["TagTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 MappingParametersTypeDef = TypedDict(
@@ -561,18 +732,28 @@ OutputDescriptionTypeDef = TypedDict(
     total=False,
 )
 
-OutputTypeDef = TypedDict(
-    "OutputTypeDef",
+_RequiredOutputTypeDef = TypedDict(
+    "_RequiredOutputTypeDef",
     {
         "Name": str,
+        "DestinationSchema": "DestinationSchemaTypeDef",
+    },
+)
+_OptionalOutputTypeDef = TypedDict(
+    "_OptionalOutputTypeDef",
+    {
         "KinesisStreamsOutput": "KinesisStreamsOutputTypeDef",
         "KinesisFirehoseOutput": "KinesisFirehoseOutputTypeDef",
         "LambdaOutput": "LambdaOutputTypeDef",
-        "DestinationSchema": "DestinationSchemaTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
+    total=False,
 )
 
+
+class OutputTypeDef(_RequiredOutputTypeDef, _OptionalOutputTypeDef):
+    pass
+
+
 _RequiredOutputUpdateTypeDef = TypedDict(
     "_RequiredOutputUpdateTypeDef",
     {
@@ -771,6 +952,29 @@ class SourceSchemaTypeDef(_RequiredSourceSchemaTypeDef, _OptionalSourceSchemaTyp
     pass
 
 
+StartApplicationRequestTypeDef = TypedDict(
+    "StartApplicationRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "InputConfigurations": List["InputConfigurationTypeDef"],
+    },
+)
+
+StopApplicationRequestTypeDef = TypedDict(
+    "StopApplicationRequestTypeDef",
+    {
+        "ApplicationName": str,
+    },
+)
+
+TagResourceRequestTypeDef = TypedDict(
+    "TagResourceRequestTypeDef",
+    {
+        "ResourceARN": str,
+        "Tags": List["TagTypeDef"],
+    },
+)
+
 _RequiredTagTypeDef = TypedDict(
     "_RequiredTagTypeDef",
     {
@@ -788,3 +992,21 @@ _OptionalTagTypeDef = TypedDict(
 
 class TagTypeDef(_RequiredTagTypeDef, _OptionalTagTypeDef):
     pass
+
+
+UntagResourceRequestTypeDef = TypedDict(
+    "UntagResourceRequestTypeDef",
+    {
+        "ResourceARN": str,
+        "TagKeys": List[str],
+    },
+)
+
+UpdateApplicationRequestTypeDef = TypedDict(
+    "UpdateApplicationRequestTypeDef",
+    {
+        "ApplicationName": str,
+        "CurrentApplicationVersionId": int,
+        "ApplicationUpdate": "ApplicationUpdateTypeDef",
+    },
+)
